<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <source>Details</source>
        <translation>Dettagli</translation>
    </message>
    <message>
        <source>Guess</source>
        <translation>Risposta</translation>
    </message>
    <message>
        <source>Found</source>
        <translation>Trovato</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normale</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Grande</translation>
    </message>
    <message>
        <source>Missed</source>
        <translation>Perso</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Successo</translation>
    </message>
    <message>
        <source>Game Over</source>
        <translation>Fine partita</translation>
    </message>
    <message numerus="yes">
        <source>%1 of %n point(s)</source>
        <translation>
            <numerusform>%1 di %n punto</numerusform>
            <numerusform>%1 di %n punti</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>3 of %n point(s)</source>
        <translation>
            <numerusform>3 di %n punto</numerusform>
            <numerusform>3 di %n punti</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>2 of %n point(s)</source>
        <translation>
            <numerusform>2 di %n punto</numerusform>
            <numerusform>2 di %n punti</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>1 of %n point(s)</source>
        <translation>
            <numerusform>1 di %n punto</numerusform>
            <numerusform>1 di %n punti</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>0 of %n point(s)</source>
        <translation>
            <numerusform>0 di %n punto</numerusform>
            <numerusform>0 di %n punti</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation>
            <numerusform>%n punti</numerusform>
            <numerusform>%n punti</numerusform>
        </translation>
    </message>
    <message>
        <source>The maximum score was calculated from the following thirty words:</source>
        <translation>Il punteggio massimo è stato calcolato dalle seguenti trenta parole;</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>m:ss</source>
        <translation>m:ss</translation>
    </message>
    <message numerus="yes">
        <source>%n guesses(s)</source>
        <translation>
            <numerusform>%n risposta</numerusform>
            <numerusform>%n risposte</numerusform>
        </translation>
    </message>
    <message>
        <source>+%1</source>
        <translation>+%1</translation>
    </message>
    <message numerus="yes">
        <source>%n strike(s)</source>
        <translation>
            <numerusform>%n colpo</numerusform>
            <numerusform>%n colpi</numerusform>
        </translation>
    </message>
    <message>
        <source>Tanglet</source>
        <translation>Tanglet</translation>
    </message>
    <message>
        <source>Classic</source>
        <translation>Classico</translation>
    </message>
    <message>
        <source>Refill</source>
        <translation>Ricarica</translation>
    </message>
    <message>
        <source>Stamina</source>
        <translation>Resistenza</translation>
    </message>
    <message>
        <source>Strikeout</source>
        <translation>Eliminazione</translation>
    </message>
    <message>
        <source>Allotment</source>
        <translation>Ripartizione</translation>
    </message>
    <message>
        <source>Discipline</source>
        <translation>Disciplina</translation>
    </message>
    <message>
        <source>Unlimited</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and increases on correct guesses.</source>
        <translation>Conto alla rovescia da 30 secondi e aumenta su risposte corrette.</translation>
    </message>
    <message>
        <source>Counts down from 3 minutes.</source>
        <translation>Conto alla rovescia da 3 minuti.</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and refills on correct guesses.</source>
        <translation>Conto alla rovescia da 30 secondi e ricariche su risposte corrette.</translation>
    </message>
    <message>
        <source>Counts down from 45 seconds and pauses on correct guesses.</source>
        <translation>Conto alla rovescia da 45 secondi e pausa su risposte corrette.</translation>
    </message>
    <message>
        <source>Game ends after 3 incorrect guesses.</source>
        <translation>Il gioco termina dopo 30 risposte sbagliate</translation>
    </message>
    <message>
        <source>Game ends after 30 guesses.</source>
        <translation>Il gioco termina dopo 30 risposte.</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
        <translation>Conto alla rovescia da 30 secondi e cresce o decresce in base alle risposte.</translation>
    </message>
    <message>
        <source>Game ends when all words are found.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Generator</name>
    <message>
        <source>Unable to read dice from file.</source>
        <translation>Impossibile leggere dal file di gioco</translation>
    </message>
    <message>
        <source>Unable to read word list from file.</source>
        <translation>Impossibile leggere la lista delle parole da file.</translation>
    </message>
</context>
<context>
    <name>LanguageDialog</name>
    <message>
        <source>Board Language</source>
        <translation>Lingua della scheda</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Personalizzato</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation>Scegli...</translation>
    </message>
    <message>
        <source>&lt;b&gt;Note:&lt;/b&gt; These settings will take effect when you start a new game.</source>
        <translation>&lt;b&gt;Nota:&lt;/b&gt; Queste impostazioni saranno effettive all&apos;avvio di un nuovo gioco.</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Lingua:</translation>
    </message>
    <message>
        <source>Dice:</source>
        <translation>Gioco:</translation>
    </message>
    <message>
        <source>Word list:</source>
        <translation>Lista delle parole:</translation>
    </message>
    <message>
        <source>Dictionary:</source>
        <translation>Dizionario:</translation>
    </message>
    <message>
        <source>Choose Dice File</source>
        <translation>Seleziona un file di gioco</translation>
    </message>
    <message>
        <source>Choose Word List File</source>
        <translation>Seleziona il file della lista parole</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Seleziona la lingua dell&apos;applicazione</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Lingua di sistema&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Note</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Si prega di riavviare l&apos;appicazione per rendere effetivo il cambio di lingua.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Nuova partita</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Totale parole:</translation>
    </message>
    <message>
        <source>Minimum Word Length:</source>
        <translation>Lunghezza minima parola:</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Basso</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Medio</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Alto</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Casuale</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n lettera</numerusform>
            <numerusform>%n lettere</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>High Scores</source>
        <translation>Punteggi massimi</translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Punteggio</translation>
    </message>
    <message>
        <source>Maximum</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>N/A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>#%1</source>
        <translation>#%1</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tanglet</source>
        <translation>Tanglet</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Paused&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Click to resume playing.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;In pausa&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Clicca per riprendere il gioco.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Loading game...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Attendere prego&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Sto caricando una partita...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Clicca per avviare una nuova partita</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Generating a new board...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Attendere prego&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Sto generando una nuova scheda...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Optimizing word list...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Attendere prego&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Sto ottimizzando l&apos;elenco di parole...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Partita</translation>
    </message>
    <message>
        <source>New &amp;Game...</source>
        <translation>Nuova &amp;Partita...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Maiscolo+N</translation>
    </message>
    <message>
        <source>&amp;New Roll</source>
        <translation>&amp;Nuova Scheda</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Scegli...</translation>
    </message>
    <message>
        <source>&amp;Share...</source>
        <translation>&amp;Condividi...</translation>
    </message>
    <message>
        <source>&amp;End</source>
        <translation>&amp;Termina</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pausa</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Dettagli</translation>
    </message>
    <message>
        <source>&amp;High Scores</source>
        <translation>&amp;Punteggi massimi</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Termina</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Impostazioni</translation>
    </message>
    <message>
        <source>Show &amp;Maximum Score</source>
        <translation>Mostra &amp;Punteggio Massimo</translation>
    </message>
    <message>
        <source>&amp;Never</source>
        <translation>&amp;Mai</translation>
    </message>
    <message>
        <source>&amp;End Of Game</source>
        <translation>&amp;Fine partita</translation>
    </message>
    <message>
        <source>&amp;Always</source>
        <translation>&amp;Sempre</translation>
    </message>
    <message>
        <source>Show Missed &amp;Words</source>
        <translation>Mosta &amp;parole perse</translation>
    </message>
    <message>
        <source>Show Word &amp;Counts</source>
        <translation>Mostra &amp;contatore parole</translation>
    </message>
    <message>
        <source>&amp;Board Language...</source>
        <translation>&amp;Lingua scheda</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Lingua &amp;Applicazione...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Controlli</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Informazioni su</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Informazioni su &amp;Qt</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Tanglet %1</source>
        <translation>Tanglet %1</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Informazioni su </translation>
    </message>
    <message>
        <source>A single player variant of &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</source>
        <translation>Una variante a singolo giocatore di  &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Rilasciato sotto licenza  &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>English word list is based on &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; by Kevin Atkinson</source>
        <translation>La lista di parole inglesi è basata su  &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; di Kevin Atkinson</translation>
    </message>
    <message>
        <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
        <translation>La lista  di parole ebraiche è basata su &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; di Nadav Har&apos;El and Dan Kenigsberg</translation>
    </message>
    <message>
        <source>Import Game</source>
        <translation>Importa partita</translation>
    </message>
    <message>
        <source>Tanglet Games (*.tanglet)</source>
        <translation>Partita Tanglet (*.tanglet)</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Impossibile avviare la partita richiesta</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <source>Export Game</source>
        <translation>Esporta partita</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Domanda</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Termina la partita ?</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Dettagli</translation>
    </message>
    <message>
        <source>Board Size:</source>
        <translation>Dimensioni Scheda:</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normale</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Largo</translation>
    </message>
    <message>
        <source>Word Density:</source>
        <translation>Densità parole:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Lunghezza parola:</translation>
    </message>
    <message>
        <source>%1 or more letters</source>
        <translation>%1 o più lettere</translation>
    </message>
    <message>
        <source>Game Type:</source>
        <translation>Tipo di gioco:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Descrizione:</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Controlli</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Gioca col mouse:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Seleziona una parola:&lt;/b&gt; Clicca sulle lettere di una parola.&lt;br&gt;&lt;b&gt;Crea una risposta:&lt;/b&gt; Clicca sull&apos;ultima lettera selezionata.&lt;br&gt;&lt;b&gt;Cancella le  lettere:&lt;/b&gt; Clicca sulla prima lettera selezionata.&lt;br&gt;&lt;b&gt;Cancella la parola:&lt;/b&gt; Clicca due volte sulla prima lettera selezionata.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Gioca con la tastiera:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Seleziona una parola:&lt;/b&gt; Scrivi le lettere di una palora.&lt;br&gt;&lt;b&gt;Dai una risposta:&lt;/b&gt; Premi invio.&lt;br&gt;&lt;b&gt;Cancella la word:&lt;/b&gt; Premi Ctrl+Backspace.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WordCounts</name>
    <message>
        <source>Letters:</source>
        <translation>Lettere:</translation>
    </message>
    <message>
        <source>Found:</source>
        <translation>Trovato:</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</source>
        <translation>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</source>
        <translation>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;%2/%3</source>
        <translation>%1&lt;br&gt;%2/%3</translation>
    </message>
</context>
<context>
    <name>WordTree</name>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation>
            <numerusform>%n punto</numerusform>
            <numerusform>%n punti</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Word finding game</source>
        <translation>Gioco di ricerca parole</translation>
    </message>
    <message>
        <source>A game file to play.</source>
        <translation>Un file gioco per giocare.</translation>
    </message>
</context>
</TS>
